==> cloudt-boot-starter-mq-0.2.3.2-20230727.084742-1-sources.jar: com/elitescloud/boot/mq/compensate/controller/SysRocketMqConsumeLogController.java <==
package com.elitescloud.boot.mq.compensate.controller;

import com.elitescloud.boot.mq.compensate.model.vo.SysRocketMqConsumeLogVO;
import com.elitescloud.boot.mq.compensate.param.SysRocketMqConsumeLogCreateParam;
import com.elitescloud.boot.mq.compensate.param.SysRocketMqConsumeLogQueryParam;
import com.elitescloud.boot.mq.compensate.service.SysRocketMqConsumeLogService;
import com.elitescloud.cloudt.common.base.ApiCode;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.common.base.PagingVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.val;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 功能说明
 * </p>
 *
 * @author roman.zhang
 * @since 2022-04-01 16:07:23
 */
@ResponseBody
@RequestMapping("/sys/sysRocketMqConsumeLog")
@Api(value = "架构补偿机制-消费记录", tags = {"架构补偿机制-消费记录"})
public class SysRocketMqConsumeLogController {

    private final SysRocketMqConsumeLogService sysRocketMqConsumeLogService;

    public SysRocketMqConsumeLogController(SysRocketMqConsumeLogService sysRocketMqConsumeLogService) {
        this.sysRocketMqConsumeLogService = sysRocketMqConsumeLogService;
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/findIdOne/{id}")
    @ApiOperation("通过主键查询单条数据")
    ApiResult<SysRocketMqConsumeLogVO>  findIdOne(@PathVariable  Long id){
        return sysRocketMqConsumeLogService.findIdOne(id).map(ApiResult::ok)
        .orElse(ApiResult.fail(ApiCode.NOT_FOUND));
    }
    
    /**
     * 根据关键字段查询数据
     * @param key 参数
     * @return 数据
     */
    @GetMapping("/findCodeOne/{key}")
    @ApiOperation("根据关键字段查询数据")
    public ApiResult<SysRocketMqConsumeLogVO>  findCodeOne(@PathVariable  String key){
        return sysRocketMqConsumeLogService.findCodeOne(key).map(ApiResult::ok)
        .orElse(ApiResult.fail(ApiCode.NOT_FOUND));
    }
    
    /**
     * 分页查询
     *
     * @param param 分类查询、分页和排序对象
     * @return 多条数据
     */
    @PostMapping("/search")
    @ApiOperation("分页查询")
    public  ApiResult<PagingVO<SysRocketMqConsumeLogVO>> search(@RequestBody SysRocketMqConsumeLogQueryParam param){
        val ret = sysRocketMqConsumeLogService.search(param);
        return ApiResult.ok(ret); 
    }
    
     /**
     * 新增数据
     *
     * @param param 新增数据
     * @return 新增数据情况
     */
    @PostMapping("/createOne")
    @ApiOperation("新增数据")
    public ApiResult<Object> createOne(@RequestBody SysRocketMqConsumeLogCreateParam param){
         return  ApiResult.ok( sysRocketMqConsumeLogService.createOne(param));
    }
    /**
     * 批量新增数据
     *
     * @param list 对象集合
     */
    @PostMapping("/createBatch")
    @ApiOperation("批量新增数据")
    public ApiResult<Object> createBatch(@RequestBody List<SysRocketMqConsumeLogCreateParam> list){
        return ApiResult.ok( sysRocketMqConsumeLogService.createBatch(list));
    }
//
//   /**
//     * 修改数据
//     *
//     * @param param 修改对象
//     * @return 修改数据详情
//     */
//    @PutMapping("/update")
//    @ApiOperation("修改数据")
//    public ApiResult<Object> update(@RequestBody SysRocketMqConsumeLogUpdateParam param){
//        sysRocketMqConsumeLogService.update(param);
//        return ApiResult.ok();
//    }
    
    /**
     * 根据主键删除数据
     *
     * @param  id 主键
     * @return 删除情况
     */
    @DeleteMapping("/deleteOne/{id}")
    @ApiOperation("根据主键删除数据")
    public ApiResult<Object> deleteOne(@PathVariable Long id){
        sysRocketMqConsumeLogService.deleteOne(id);
        return ApiResult.ok();
    }
    
    /**
     * 批量删除
     *
     * @param ids 删除数据集合
     */
    @DeleteMapping("/deleteBatch")
    @ApiOperation("批量删除")
    public ApiResult<Object> deleteBatch(@RequestBody List<Long> ids){
        sysRocketMqConsumeLogService.deleteBatch(ids);
        return ApiResult.ok();
    }
    
    /**
     * 逻辑删除
     *
     * @param id 更新数据
     */
    @PutMapping("/updateDeleteFlag/{id}")
    @ApiOperation("逻辑删除")
    public ApiResult<Object> updateDeleteFlag(@PathVariable Long id){
        sysRocketMqConsumeLogService.updateDeleteFlag(id);
        return ApiResult.ok();
    }
}

==> cloudt-boot-starter-mq-3.1.2.7-20230408.135715-1-sources.jar: com/elitescloud/boot/mq/compensate/controller/SysRocketMqConsumeLogController.java <==
package com.elitescloud.boot.mq.compensate.controller;

import com.elitescloud.boot.mq.compensate.model.vo.SysRocketMqConsumeLogVO;
import com.elitescloud.boot.mq.compensate.param.SysRocketMqConsumeLogCreateParam;
import com.elitescloud.boot.mq.compensate.param.SysRocketMqConsumeLogQueryParam;
import com.elitescloud.boot.mq.compensate.service.SysRocketMqConsumeLogService;
import com.elitescloud.cloudt.common.base.ApiCode;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.common.base.PagingVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.val;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 功能说明
 * </p>
 *
 * @author roman.zhang
 * @since 2022-04-01 16:07:23
 */
@ResponseBody
@RequestMapping("/sys/sysRocketMqConsumeLog")
@Api(value = "架构补偿机制-消费记录", tags = {"架构补偿机制-消费记录"})
public class SysRocketMqConsumeLogController {

    @Autowired
    private SysRocketMqConsumeLogService sysRocketMqConsumeLogService;
   
    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/findIdOne/{id}")
    @ApiOperation("通过主键查询单条数据")
    ApiResult<SysRocketMqConsumeLogVO>  findIdOne(@PathVariable  Long id){
        return sysRocketMqConsumeLogService.findIdOne(id).map(ApiResult::ok)
        .orElse(ApiResult.fail(ApiCode.NOT_FOUND));
    }
    
    /**
     * 根据关键字段查询数据
     * @param key 参数
     * @return 数据
     */
    @GetMapping("/findCodeOne/{key}")
    @ApiOperation("根据关键字段查询数据")
    public ApiResult<SysRocketMqConsumeLogVO>  findCodeOne(@PathVariable  String key){
        return sysRocketMqConsumeLogService.findCodeOne(key).map(ApiResult::ok)
        .orElse(ApiResult.fail(ApiCode.NOT_FOUND));
    }
    
    /**
     * 分页查询
     *
     * @param param 分类查询、分页和排序对象
     * @return 多条数据
     */
    @PostMapping("/search")
    @ApiOperation("分页查询")
    public  ApiResult<PagingVO<SysRocketMqConsumeLogVO>> search(@RequestBody SysRocketMqConsumeLogQueryParam param){
        val ret = sysRocketMqConsumeLogService.search(param);
        return ApiResult.ok(ret); 
    }
    
     /**
     * 新增数据
     *
     * @param param 新增数据
     * @return 新增数据情况
     */
    @PostMapping("/createOne")
    @ApiOperation("新增数据")
    public ApiResult<Object> createOne(@RequestBody SysRocketMqConsumeLogCreateParam param){
         return  ApiResult.ok( sysRocketMqConsumeLogService.createOne(param));
    }
    /**
     * 批量新增数据
     *
     * @param list 对象集合
     */
    @PostMapping("/createBatch")
    @ApiOperation("批量新增数据")
    public ApiResult<Object> createBatch(@RequestBody List<SysRocketMqConsumeLogCreateParam> list){
        return ApiResult.ok( sysRocketMqConsumeLogService.createBatch(list));
    }
//
//   /**
//     * 修改数据
//     *
//     * @param param 修改对象
//     * @return 修改数据详情
//     */
//    @PutMapping("/update")
//    @ApiOperation("修改数据")
//    public ApiResult<Object> update(@RequestBody SysRocketMqConsumeLogUpdateParam param){
//        sysRocketMqConsumeLogService.update(param);
//        return ApiResult.ok();
//    }
    
    /**
     * 根据主键删除数据
     *
     * @param  id 主键
     * @return 删除情况
     */
    @DeleteMapping("/deleteOne/{id}")
    @ApiOperation("根据主键删除数据")
    public ApiResult<Object> deleteOne(@PathVariable Long id){
        sysRocketMqConsumeLogService.deleteOne(id);
        return ApiResult.ok();
    }
    
    /**
     * 批量删除
     *
     * @param ids 删除数据集合
     */
    @DeleteMapping("/deleteBatch")
    @ApiOperation("批量删除")
    public ApiResult<Object> deleteBatch(@RequestBody List<Long> ids){
        sysRocketMqConsumeLogService.deleteBatch(ids);
        return ApiResult.ok();
    }
    
    /**
     * 逻辑删除
     *
     * @param id 更新数据
     */
    @PutMapping("/updateDeleteFlag/{id}")
    @ApiOperation("逻辑删除")
    public ApiResult<Object> updateDeleteFlag(@PathVariable Long id){
        sysRocketMqConsumeLogService.updateDeleteFlag(id);
        return ApiResult.ok();
    }
}
